ibpmodel package
================

ibpmodel.ibpcalc module
-----------------------

.. automodule:: ibpmodel.ibpcalc
   :members:
   :undoc-members:
   :show-inheritance:

ibpmodel.ibpforward module
--------------------------

.. automodule:: ibpmodel.ibpforward
   :members:
   :undoc-members:
   :show-inheritance:
